@@ -369,7 +369,7 @@ from ae.console import ConsoleApp                   # type: ignore
 from ae.files import FilesRegister, RegisteredFile  # type: ignore
 
 
-__version__ = '0.0.20'
+__version__ = '0.0.21'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -378,7 +378,7 @@ APP_STATE_SECTION_NAME = 'aeAppState'           #: config section name for to st
 
 #: config variable name for to store the current application state version
 APP_STATE_VERSION_VAR_NAME = 'app_state_version'
-APP_STATE_CURRENT_VERSION = 2                   #: current application state version
+APP_STATE_CURRENT_VERSION = 3                   #: current application state version
 
 MIN_FONT_SIZE = 15.0                            #: minimum font size in pixels
 MAX_FONT_SIZE = 99.0                            #: maximum font size in pixels
@@ -660,20 +660,38 @@ class MainAppBase(ConsoleApp, ABC):
             if key == 'flow_id' and flow_action(val) == 'focus':
                 self._last_focus_flow_id = val
 
+        def upd_app_state(upd_key, upd_val, old_name=''):
+            """ update and optionally rename app state in app instance and config file. """
+            self.change_app_state(upd_key, upd_val, send_event=False)
+            self.set_var(upd_key, upd_val, section=APP_STATE_SECTION_NAME, old_name=old_name)
+
         config_file_version = app_state.get(APP_STATE_VERSION_VAR_NAME, 0)
         for version in range(config_file_version, APP_STATE_CURRENT_VERSION):
-            key, val = '', None
             if version == 0:
-                key, val = 'light_theme', True
+                upd_app_state('light_theme', True)
             elif version == 1:
-                key, val = 'sound_volume', 0.96
-            if key:
-                self.change_app_state(key, val, send_event=False)
-                self.set_var(key, val, section=APP_STATE_SECTION_NAME)
+                upd_app_state('sound_volume', 0.96)
+            elif version == 2:
+                if 'context_id' not in app_state:
+                    continue    # update only LiszApp apps
+
+                def mig_node(parent_node):
+                    """ recursively migrate sub_list to node key. """
+                    new_parent_node = list()
+                    for item in parent_node:
+                        node = item.pop('sub_list', None)
+                        if node is not None:
+                            item['node'] = mig_node(node)
+                        new_parent_node.append(item)
+                    return new_parent_node
+                upd_app_state('root_node', mig_node(app_state['data_tree']), 'data_tree')
+                upd_app_state('flow_path_ink', app_state['context_path_ink'], 'context_path_ink')
+                upd_app_state('flow_id_ink', app_state['context_id_ink'], 'context_id_ink')
+                upd_app_state('flow_path', app_state['context_path'], 'context_path')
+                upd_app_state('flow_id', app_state['context_id'], 'context_id')
+
         if config_file_version < APP_STATE_CURRENT_VERSION:
-            key, val = APP_STATE_VERSION_VAR_NAME, APP_STATE_CURRENT_VERSION
-            self.change_app_state(key, val, send_event=False)
-            self.set_var(key, val, section=APP_STATE_SECTION_NAME)
+            upd_app_state(APP_STATE_VERSION_VAR_NAME, APP_STATE_CURRENT_VERSION)
 
     def _update_observable_app_states(self, app_state: AppStateType):
         """ update all the observable app states.
